==> xlniuxdata-vipgame-1.0.37-20151124.073103-8-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/RebateReportPersonDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;


public class RebateReportPersonDTO {
    private String person;
    private Double finished;
    private Long kpi;
    private Double kpirate;
    private Double kpirateRc;
    private Double kpirateYj;
    private Double finishedRiChang;
    private Double finishedYeJi;

    public Double getKpirateRc() {
        return kpirateRc;
    }

    public void setKpirateRc(Double kpirateRc) {
        this.kpirateRc = kpirateRc;
    }

    public Double getKpirateYj() {
        return kpirateYj;
    }

    public void setKpirateYj(Double kpirateYj) {
        this.kpirateYj = kpirateYj;
    }

    public Double getFinishedRiChang() {
        return finishedRiChang;
    }

    public void setFinishedRiChang(Double finishedRiChang) {
        this.finishedRiChang = finishedRiChang;
    }

    public Double getFinishedYeJi() {
        return finishedYeJi;
    }

    public void setFinishedYeJi(Double finishedYeJi) {
        this.finishedYeJi = finishedYeJi;
    }

    public Double getFinished() {
        return finished;
    }

    public void setFinished(Double finished) {
        this.finished = finished;
    }

    public Long getKpi() {
        return kpi;
    }

    public void setKpi(Long kpi) {
        this.kpi = kpi;
    }

    public Double getKpirate() {
        return kpirate;
    }

    public void setKpirate(Double kpirate) {
        this.kpirate = kpirate;
    }

    public String getPerson() {
        return person;
    }

    public void setPerson(String person) {
        this.person = person;
    }
}

==> xlniuxdata-vipgame-1.0.42-20160119.014201-11-sources.jar: com/xunlei/niux/data/vipgame/dto/vic/RebateReportPersonDTO.java <==
package com.xunlei.niux.data.vipgame.dto.vic;


public class RebateReportPersonDTO {
    private String person;
    private Double finished;
    private Long kpi;
    private Long kpiRc;
    private Long kpiYj;
    private Double kpirate;
    private Double kpirateRc;
    private Double kpirateYj;
    private Double finishedRiChang;
    private Double finishedYeJi;

    public Long getKpiRc() {
        return kpiRc;
    }

    public void setKpiRc(Long kpiRc) {
        this.kpiRc = kpiRc;
    }

    public Long getKpiYj() {
        return kpiYj;
    }

    public void setKpiYj(Long kpiYj) {
        this.kpiYj = kpiYj;
    }

    public Double getKpirateRc() {
        return kpirateRc;
    }

    public void setKpirateRc(Double kpirateRc) {
        this.kpirateRc = kpirateRc;
    }

    public Double getKpirateYj() {
        return kpirateYj;
    }

    public void setKpirateYj(Double kpirateYj) {
        this.kpirateYj = kpirateYj;
    }

    public Double getFinishedRiChang() {
        return finishedRiChang;
    }

    public void setFinishedRiChang(Double finishedRiChang) {
        this.finishedRiChang = finishedRiChang;
    }

    public Double getFinishedYeJi() {
        return finishedYeJi;
    }

    public void setFinishedYeJi(Double finishedYeJi) {
        this.finishedYeJi = finishedYeJi;
    }

    public Double getFinished() {
        return finished;
    }

    public void setFinished(Double finished) {
        this.finished = finished;
    }

    public Long getKpi() {
        return kpi;
    }

    public void setKpi(Long kpi) {
        this.kpi = kpi;
    }

    public Double getKpirate() {
        return kpirate;
    }

    public void setKpirate(Double kpirate) {
        this.kpirate = kpirate;
    }

    public String getPerson() {
        return person;
    }

    public void setPerson(String person) {
        this.person = person;
    }
}
